tonalitytools.TonalFunction
===========================

.. abjad-lineage:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction

.. autoclass:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.bass_scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.figured_bass_string
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.markup
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.quality
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.root_scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.scale_degree
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.suspension
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.symbolic_string
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.TonalFunction.TonalFunction.TonalFunction.__repr__
   :noindex:
